==> webkit2gtk_2.28.0.orig.tar.xz: webkitgtk-2.28.0/Source/WebCore/platform/mediastream/libwebrtc/LibWebRTCProviderCocoa.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "LibWebRTCProvider.h"

#if USE(LIBWEBRTC)

namespace webrtc {
class VideoDecoderFactory;
class VideoEncoderFactory;
}

namespace WebCore {

class WEBCORE_EXPORT LibWebRTCProviderCocoa : public LibWebRTCProvider {
public:
    LibWebRTCProviderCocoa() = default;
    ~LibWebRTCProviderCocoa();

    std::unique_ptr<webrtc::VideoDecoderFactory> createDecoderFactory() override;

private:
    void setActive(bool) final;
    std::unique_ptr<webrtc::VideoEncoderFactory> createEncoderFactory() final;

    void setH264HardwareEncoderAllowed(bool allowed) final;
};

} // namespace WebCore

#endif

==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/platform/mediastream/libwebrtc/LibWebRTCProviderCocoa.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "LibWebRTCProvider.h"

#if USE(LIBWEBRTC)

#include <wtf/TZoneMalloc.h>

namespace webrtc {
class VideoDecoderFactory;
class VideoEncoderFactory;
}

namespace WebCore {

class WEBCORE_EXPORT LibWebRTCProviderCocoa : public LibWebRTCProvider {
    WTF_MAKE_TZONE_ALLOCATED_EXPORT(LibWebRTCProviderCocoa, WEBCORE_EXPORT);
public:
    LibWebRTCProviderCocoa() = default;
    ~LibWebRTCProviderCocoa();

    std::unique_ptr<webrtc::VideoDecoderFactory> createDecoderFactory() override;
    std::unique_ptr<webrtc::VideoEncoderFactory> createEncoderFactory() override;

private:
    std::optional<MediaCapabilitiesInfo> computeVPParameters(const VideoConfiguration&) final;
    bool isVPSoftwareDecoderSmooth(const VideoConfiguration&) final;
};

} // namespace WebCore

#endif
